@@ -9,7 +9,7 @@ use Carp ();
 
 our $DEFAULT_SERVICE = 'TinyURL';
 our @EXPORT          = qw(makeashorterlink makealongerlink);
-our $VERSION         = '3.091';
+our $VERSION         = '3.092';
 $VERSION = eval $VERSION;
 
 my $style;
@@ -74,6 +74,9 @@ gives you a shortened version of it.
 Please submit any L<issues|https://github.com/p5-shorten/www-shorten/issues> you
 might have.  We appreciate all help, suggestions, noted problems, and especially patches.
 
+Note that support for extra shortening services should be released as separate modules,
+like L<WWW::Shorten::Googl> or L<WWW::Shorten::Bitly>.
+
 Support for this module is supplied primarily via the using the
 L<GitHub Issues|https://github.com/p5-shorten/www-shorten/issues> but we also
 happily respond to issues submitted to the
